"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DayPickerProvider = void 0;
var React = __importStar(require("react"));
var en_US_1 = __importDefault(require("date-fns/locale/en-US"));
var Components = __importStar(require("../../components"));
var DayPickerContext_1 = require("./DayPickerContext");
var defaultClassNames_1 = require("./defaultClassNames");
var formatters = __importStar(require("./formatters"));
var labels = __importStar(require("./labels"));
var convertModifierMatchersToArray_1 = require("./utils/convertModifierMatchersToArray");
var parseFromToProps_1 = require("./utils/parseFromToProps");
var parseModifierShortcuts_1 = require("./utils/parseModifierShortcuts");
var parseToday_1 = require("./utils/parseToday");
/**
 * The provider for the [[DayPickerContext]].
 */
function DayPickerProvider(props) {
    var _a, _b, _c, _d;
    var children = props.children, _e = props.initialProps, initialProps = _e === void 0 ? {} : _e;
    var _f = parseFromToProps_1.parseFromToProps(initialProps), fromDate = _f.fromDate, toDate = _f.toDate;
    var locale = initialProps.locale || en_US_1.default;
    var numberOfMonths = (_a = initialProps.numberOfMonths) !== null && _a !== void 0 ? _a : 1;
    var today = parseToday_1.parseToday(initialProps);
    var month = initialProps.month;
    // Default caption layout. If calendar navigation is unlimited, it must be
    // always `buttons` – as we cannot display infinite options in the dropdown.
    var captionLayout = (_b = initialProps.captionLayout) !== null && _b !== void 0 ? _b : 'buttons';
    if (!fromDate && !toDate)
        captionLayout = 'buttons';
    var modifiers = parseModifierShortcuts_1.parseModifierShortcuts(initialProps);
    var modifiersAsArray = convertModifierMatchersToArray_1.convertModifierMatchersToArray(modifiers);
    // Disable days before/after from/toDate
    if (fromDate) {
        modifiersAsArray.disabled.push({ before: fromDate });
    }
    if (toDate) {
        modifiersAsArray.disabled.push({ after: toDate });
    }
    var dir = initialProps.dir, defaultMonth = initialProps.defaultMonth, disableNavigation = initialProps.disableNavigation, fixedWeeks = initialProps.fixedWeeks, hideHead = initialProps.hideHead, modifierStyles = initialProps.modifierStyles, onDayClick = initialProps.onDayClick, onDayFocus = initialProps.onDayFocus, onDayBlur = initialProps.onDayBlur, onDayKeyDown = initialProps.onDayKeyDown, onDayKeyUp = initialProps.onDayKeyUp, onDayMouseEnter = initialProps.onDayMouseEnter, onDayMouseLeave = initialProps.onDayMouseLeave, onDayTouchCancel = initialProps.onDayTouchCancel, onDayTouchStart = initialProps.onDayTouchStart, onMonthChange = initialProps.onMonthChange, onWeekNumberClick = initialProps.onWeekNumberClick, showOutsideDays = initialProps.showOutsideDays, showWeekNumber = initialProps.showWeekNumber, footer = initialProps.footer;
    var context = {
        className: initialProps.className,
        dir: dir,
        disableNavigation: disableNavigation,
        defaultMonth: defaultMonth,
        fixedWeeks: fixedWeeks,
        hideHead: hideHead,
        modifierStyles: modifierStyles,
        onDayClick: onDayClick,
        onDayFocus: onDayFocus,
        onDayBlur: onDayBlur,
        onDayKeyDown: onDayKeyDown,
        onDayKeyUp: onDayKeyUp,
        onDayMouseEnter: onDayMouseEnter,
        onDayMouseLeave: onDayMouseLeave,
        onDayTouchCancel: onDayTouchCancel,
        onDayTouchStart: onDayTouchStart,
        onMonthChange: onMonthChange,
        onWeekNumberClick: onWeekNumberClick,
        showOutsideDays: showOutsideDays,
        showWeekNumber: showWeekNumber,
        footer: footer,
        captionLayout: captionLayout,
        fromDate: fromDate,
        hideToday: initialProps.today === 'off',
        locale: locale,
        modifierClassNames: (_c = initialProps.modifierClassNames) !== null && _c !== void 0 ? _c : {},
        modifierPrefix: 'rdp-day_',
        modifiers: modifiersAsArray,
        month: month,
        numberOfMonths: numberOfMonths,
        style: initialProps.style,
        styles: (_d = initialProps.styles) !== null && _d !== void 0 ? _d : {},
        toDate: toDate,
        today: today,
        classNames: __assign(__assign({}, defaultClassNames_1.defaultClassNames), initialProps.classNames),
        formatters: __assign(__assign({}, formatters), initialProps.formatters),
        labels: __assign(__assign({}, labels), initialProps.labels),
        components: __assign({ Caption: Components.Caption, CaptionLabel: Components.CaptionLabel, Day: Components.Day, DayContent: Components.DayContent, Dropdown: Components.Dropdown, Footer: Components.Footer, Head: Components.Head, IconDropdown: Components.IconDropdown, IconNext: Components.IconNext, IconPrevious: Components.IconPrevious, Row: Components.Row, WeekNumber: Components.WeekNumber }, initialProps.components)
    };
    return (React.createElement(DayPickerContext_1.DayPickerContext.Provider, { value: context }, children));
}
exports.DayPickerProvider = DayPickerProvider;
//# sourceMappingURL=DayPickerProvider.js.map