"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getPreviousMonth = void 0;
var date_fns_1 = require("date-fns");
/**
 * Returns the next previous the user can navigate to, according to the given
 * options.
 *
 * Please note that the previous month is not always the previous calendar
 * month:
 *
 * - if before the `fromDate` date, is `undefined`;
 * - if the navigation is paged, is the number of months displayed before.
 *
 */
function getPreviousMonth(startingMonth, options) {
    if (options.disableNavigation) {
        return undefined;
    }
    var fromDate = options.fromDate, pagedNavigation = options.pagedNavigation, _a = options.numberOfMonths, numberOfMonths = _a === void 0 ? 1 : _a;
    var offset = pagedNavigation ? numberOfMonths : 1;
    var month = date_fns_1.startOfMonth(startingMonth);
    if (!fromDate) {
        return date_fns_1.addMonths(month, -offset);
    }
    var monthsDiff = date_fns_1.differenceInCalendarMonths(month, fromDate);
    if (monthsDiff <= 0) {
        return undefined;
    }
    // Jump back as the number of months when paged navigation
    return date_fns_1.addMonths(month, -offset);
}
exports.getPreviousMonth = getPreviousMonth;
//# sourceMappingURL=getPreviousMonth.js.map