"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var date_fns_1 = require("date-fns");
var getPreviousMonth_1 = require("./getPreviousMonth");
var startingMonth = new Date(2020, 4, 31);
describe('when number of months is 1', function () {
    describe('when the navigation is disabled', function () {
        var disableNavigation = true;
        it('the previous month is undefined', function () {
            var result = getPreviousMonth_1.getPreviousMonth(startingMonth, { disableNavigation: disableNavigation });
            expect(result).toBe(undefined);
        });
    });
    describe('when in the navigable range', function () {
        var fromDate = date_fns_1.addMonths(startingMonth, -3);
        it('the previous month is not undefined', function () {
            var result = getPreviousMonth_1.getPreviousMonth(startingMonth, { fromDate: fromDate });
            var expectedPrevMonth = date_fns_1.addMonths(startingMonth, -1);
            expect(result && date_fns_1.isSameMonth(result, expectedPrevMonth)).toBeTruthy();
        });
    });
    describe('when not in the navigable range', function () {
        var fromDate = startingMonth;
        it('the previous month is undefined', function () {
            var result = getPreviousMonth_1.getPreviousMonth(startingMonth, { fromDate: fromDate });
            expect(result).toBe(undefined);
        });
    });
});
describe('when displaying 3 months', function () {
    var numberOfMonths = 3;
    describe('when the navigation is paged', function () {
        var pagedNavigation = true;
        it('the previous month is 3 months back', function () {
            var result = getPreviousMonth_1.getPreviousMonth(startingMonth, {
                numberOfMonths: numberOfMonths,
                pagedNavigation: pagedNavigation
            });
            var expectedPrevMonth = date_fns_1.addMonths(startingMonth, -numberOfMonths);
            expect(result && date_fns_1.isSameMonth(result, expectedPrevMonth)).toBeTruthy();
        });
    });
    describe('when the navigation is not paged', function () {
        var pagedNavigation = false;
        it('the previous month is 1 months back', function () {
            var result = getPreviousMonth_1.getPreviousMonth(startingMonth, {
                numberOfMonths: numberOfMonths,
                pagedNavigation: pagedNavigation
            });
            var expectedPrevMonth = date_fns_1.addMonths(startingMonth, -1);
            expect(result && date_fns_1.isSameMonth(result, expectedPrevMonth)).toBeTruthy();
        });
    });
});
//# sourceMappingURL=getPreviousMonth.test.js.map