"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useModifiers = void 0;
var contexts_1 = require("../../contexts");
var getModifierStatus_1 = require("./utils/getModifierStatus");
/** Return the modifiers and its styles for the specified date. */
function useModifiers(date) {
    var _a;
    var context = contexts_1.useDayPicker();
    var _b = contexts_1.useSelectSingle(), isSingleMode = _b.isSingleMode, single = __rest(_b, ["isSingleMode"]);
    var _c = contexts_1.useSelectMultiple(), isMultipleMode = _c.isMultipleMode, multiple = __rest(_c, ["isMultipleMode"]);
    var _d = contexts_1.useSelectRange(), isRangeMode = _d.isRangeMode, range = __rest(_d, ["isRangeMode"]);
    var today = !context.hideToday ? context.today : undefined;
    // Add to the modifiers in context those coming from selection
    var modifiers = __assign(__assign({}, context.modifiers), { today: (_a = context.modifiers.today) !== null && _a !== void 0 ? _a : [today], disabled: context.modifiers.disabled });
    if (isSingleMode) {
        if (single.modifiers.selected) {
            modifiers.selected = single.modifiers.selected;
        }
    }
    else if (isMultipleMode) {
        if (multiple.modifiers.selected) {
            modifiers.selected = multiple.modifiers.selected;
        }
        if (multiple.modifiers.disabled) {
            modifiers.disabled = modifiers.disabled.concat(multiple.modifiers.disabled);
        }
    }
    else if (isRangeMode) {
        if (range.modifiers.selected) {
            modifiers.selected = range.modifiers.selected;
        }
        if (range.modifiers.range_start) {
            modifiers.range_start = range.modifiers.range_start;
        }
        if (range.modifiers.range_middle) {
            modifiers.range_middle = range.modifiers.range_middle;
        }
        if (range.modifiers.range_end) {
            modifiers.range_end = range.modifiers.range_end;
        }
        if (range.modifiers.disabled) {
            modifiers.disabled = modifiers.disabled.concat(range.modifiers.disabled);
        }
    }
    var status = getModifierStatus_1.getModifierStatus(date, modifiers);
    var modifierClassNames = [];
    Object.keys(status)
        .filter(function (modifier) { return Boolean(status[modifier]); })
        .forEach(function (modifier) {
        var customClassName = context.modifierClassNames[modifier];
        if (customClassName) {
            modifierClassNames.push(customClassName);
        }
        else {
            modifierClassNames.push("" + context.modifierPrefix + modifier);
        }
    });
    var modifierStyle = {};
    if (context.modifierStyles) {
        Object.keys(status).forEach(function (modifier) {
            var _a;
            modifierStyle = __assign(__assign({}, modifierStyle), (_a = context.modifierStyles) === null || _a === void 0 ? void 0 : _a[modifier]);
        });
    }
    return {
        modifiers: status,
        modifierClassNames: modifierClassNames,
        modifierStyle: modifierStyle
    };
}
exports.useModifiers = useModifiers;
//# sourceMappingURL=useModifiers.js.map