import * as React from 'react';
import { render, screen } from '@testing-library/react';
import { ContextProvider as DayPicker } from '../../contexts';
import { Button } from './Button';
var button;
describe('when rendered without props', function () {
    beforeEach(function () {
        render(React.createElement(DayPicker, null,
            React.createElement(Button, null)));
        button = screen.getByRole('button');
    });
    test('should render a button with type "button"', function () {
        expect(button).toHaveAttribute('type', 'button');
    });
    test('should render a button with the button class name', function () {
        expect(button.classList).toContain('rdp-button');
    });
    test('should render a button with the reset class name', function () {
        expect(button.classList).toContain('rdp-button_reset');
    });
});
describe('when using a class name from props', function () {
    beforeEach(function () {
        render(React.createElement(DayPicker, null,
            React.createElement(Button, { className: "foo" })));
        button = screen.getByRole('button');
    });
    test('should add the class name', function () {
        expect(button.classList).toContain('foo');
    });
});
describe('when using custom class names from DayPicker props', function () {
    beforeEach(function () {
        render(React.createElement(DayPicker, { classNames: { button: 'foo-from-props' } },
            React.createElement(Button, null)));
        button = screen.getByRole('button');
    });
    test('should add the class name', function () {
        expect(button.classList).toContain('foo-from-props');
    });
});
describe('when using a inline style from props', function () {
    beforeEach(function () {
        render(React.createElement(DayPicker, null,
            React.createElement(Button, { style: { color: 'red' } })));
        button = screen.getByRole('button');
    });
    test('should apply the style', function () {
        expect(button.style.color).toBe('red');
    });
});
describe('when using a inline style from DayPicker props', function () {
    beforeEach(function () {
        render(React.createElement(DayPicker, { styles: { button: { color: 'blue' } } },
            React.createElement(Button, null)));
        button = screen.getByRole('button');
    });
    test('should apply the style', function () {
        expect(button.style.color).toBe('blue');
    });
});
//# sourceMappingURL=Button.test.js.map