import * as React from 'react';
import { MonthsDropdown, Navigation, YearsDropdown } from '..';
import { useDayPicker, useNavigation } from '../../contexts';
/**
 * Render the caption of a month, which includes title and navigation buttons.
 * The caption has a different layout when setting the `numberOfMonths` prop.
 */
export function Caption(props) {
    var displayMonth = props.displayMonth, _a = props.isFirst, isFirst = _a === void 0 ? false : _a, _b = props.isLast, isLast = _b === void 0 ? false : _b;
    var _c = useDayPicker(), classNames = _c.classNames, numberOfMonths = _c.numberOfMonths, disableNavigation = _c.disableNavigation, styles = _c.styles, captionLayout = _c.captionLayout, onMonthChange = _c.onMonthChange, CaptionLabel = _c.components.CaptionLabel;
    var _d = useNavigation(), previousMonth = _d.previousMonth, nextMonth = _d.nextMonth, goToMonth = _d.goToMonth;
    var handlePreviousClick = function (e) {
        if (!previousMonth)
            return;
        goToMonth(previousMonth);
        onMonthChange === null || onMonthChange === void 0 ? void 0 : onMonthChange(previousMonth);
    };
    var handleNextClick = function (e) {
        if (!nextMonth)
            return;
        goToMonth(nextMonth);
        onMonthChange === null || onMonthChange === void 0 ? void 0 : onMonthChange(nextMonth);
    };
    var handleMonthChange = function (newMonth) {
        goToMonth(newMonth);
        onMonthChange === null || onMonthChange === void 0 ? void 0 : onMonthChange(newMonth);
    };
    var captionLabel = React.createElement(CaptionLabel, { displayMonth: displayMonth });
    return (React.createElement("div", { className: classNames.caption, style: styles.caption },
        disableNavigation && captionLabel,
        !disableNavigation && (React.createElement(React.Fragment, null, captionLayout === 'dropdown' ? (React.createElement("div", { className: classNames.caption_dropdowns, style: styles.caption_dropdowns },
            React.createElement(MonthsDropdown, { onChange: handleMonthChange, displayMonth: displayMonth }),
            React.createElement(YearsDropdown, { onChange: handleMonthChange, displayMonth: displayMonth }))) : (React.createElement(React.Fragment, null,
            React.createElement(CaptionLabel, { displayMonth: displayMonth }),
            React.createElement(Navigation, { displayMonth: displayMonth, hideNext: numberOfMonths > 1 && !isLast, hidePrevious: numberOfMonths > 1 && !isFirst, nextMonth: nextMonth, previousMonth: previousMonth, onPreviousClick: handlePreviousClick, onNextClick: handleNextClick })))))));
}
//# sourceMappingURL=Caption.js.map