var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import * as React from 'react';
import enUS from 'date-fns/locale/en-US';
import * as Components from '../../components';
import { DayPickerContext } from './DayPickerContext';
import { defaultClassNames } from './defaultClassNames';
import * as formatters from './formatters';
import * as labels from './labels';
import { convertModifierMatchersToArray } from './utils/convertModifierMatchersToArray';
import { parseFromToProps } from './utils/parseFromToProps';
import { parseModifierShortcuts } from './utils/parseModifierShortcuts';
import { parseToday } from './utils/parseToday';
/**
 * The provider for the [[DayPickerContext]].
 */
export function DayPickerProvider(props) {
    var _a, _b, _c, _d;
    var children = props.children, _e = props.initialProps, initialProps = _e === void 0 ? {} : _e;
    var _f = parseFromToProps(initialProps), fromDate = _f.fromDate, toDate = _f.toDate;
    var locale = initialProps.locale || enUS;
    var numberOfMonths = (_a = initialProps.numberOfMonths) !== null && _a !== void 0 ? _a : 1;
    var today = parseToday(initialProps);
    var month = initialProps.month;
    // Default caption layout. If calendar navigation is unlimited, it must be
    // always `buttons` – as we cannot display infinite options in the dropdown.
    var captionLayout = (_b = initialProps.captionLayout) !== null && _b !== void 0 ? _b : 'buttons';
    if (!fromDate && !toDate)
        captionLayout = 'buttons';
    var modifiers = parseModifierShortcuts(initialProps);
    var modifiersAsArray = convertModifierMatchersToArray(modifiers);
    // Disable days before/after from/toDate
    if (fromDate) {
        modifiersAsArray.disabled.push({ before: fromDate });
    }
    if (toDate) {
        modifiersAsArray.disabled.push({ after: toDate });
    }
    var dir = initialProps.dir, defaultMonth = initialProps.defaultMonth, disableNavigation = initialProps.disableNavigation, fixedWeeks = initialProps.fixedWeeks, hideHead = initialProps.hideHead, modifierStyles = initialProps.modifierStyles, onDayClick = initialProps.onDayClick, onDayFocus = initialProps.onDayFocus, onDayBlur = initialProps.onDayBlur, onDayKeyDown = initialProps.onDayKeyDown, onDayKeyUp = initialProps.onDayKeyUp, onDayMouseEnter = initialProps.onDayMouseEnter, onDayMouseLeave = initialProps.onDayMouseLeave, onDayTouchCancel = initialProps.onDayTouchCancel, onDayTouchStart = initialProps.onDayTouchStart, onMonthChange = initialProps.onMonthChange, onWeekNumberClick = initialProps.onWeekNumberClick, showOutsideDays = initialProps.showOutsideDays, showWeekNumber = initialProps.showWeekNumber, footer = initialProps.footer;
    var context = {
        className: initialProps.className,
        dir: dir,
        disableNavigation: disableNavigation,
        defaultMonth: defaultMonth,
        fixedWeeks: fixedWeeks,
        hideHead: hideHead,
        modifierStyles: modifierStyles,
        onDayClick: onDayClick,
        onDayFocus: onDayFocus,
        onDayBlur: onDayBlur,
        onDayKeyDown: onDayKeyDown,
        onDayKeyUp: onDayKeyUp,
        onDayMouseEnter: onDayMouseEnter,
        onDayMouseLeave: onDayMouseLeave,
        onDayTouchCancel: onDayTouchCancel,
        onDayTouchStart: onDayTouchStart,
        onMonthChange: onMonthChange,
        onWeekNumberClick: onWeekNumberClick,
        showOutsideDays: showOutsideDays,
        showWeekNumber: showWeekNumber,
        footer: footer,
        captionLayout: captionLayout,
        fromDate: fromDate,
        hideToday: initialProps.today === 'off',
        locale: locale,
        modifierClassNames: (_c = initialProps.modifierClassNames) !== null && _c !== void 0 ? _c : {},
        modifierPrefix: 'rdp-day_',
        modifiers: modifiersAsArray,
        month: month,
        numberOfMonths: numberOfMonths,
        style: initialProps.style,
        styles: (_d = initialProps.styles) !== null && _d !== void 0 ? _d : {},
        toDate: toDate,
        today: today,
        classNames: __assign(__assign({}, defaultClassNames), initialProps.classNames),
        formatters: __assign(__assign({}, formatters), initialProps.formatters),
        labels: __assign(__assign({}, labels), initialProps.labels),
        components: __assign({ Caption: Components.Caption, CaptionLabel: Components.CaptionLabel, Day: Components.Day, DayContent: Components.DayContent, Dropdown: Components.Dropdown, Footer: Components.Footer, Head: Components.Head, IconDropdown: Components.IconDropdown, IconNext: Components.IconNext, IconPrevious: Components.IconPrevious, Row: Components.Row, WeekNumber: Components.WeekNumber }, initialProps.components)
    };
    return (React.createElement(DayPickerContext.Provider, { value: context }, children));
}
//# sourceMappingURL=DayPickerProvider.js.map