import * as React from 'react';
import { isSameMonth } from 'date-fns';
import { useDayPicker } from '..';
import { NavigationContext } from './NavigationContext';
import { getDisplayMonths } from './utils/getDisplayMonths';
import { getInitialMonth } from './utils/getInitialMonth';
import { getNextMonth } from './utils/getNextMonth';
import { getPreviousMonth } from './utils/getPreviousMonth';
/** Provides the values for the [[NavigationContext]]. */
export function NavigationProvider(props) {
    var context = useDayPicker();
    var initialMonth = getInitialMonth(context);
    var _a = React.useState(initialMonth), month = _a[0], setMonth = _a[1];
    var goToMonth = function (date) {
        if (context.disableNavigation) {
            return;
        }
        setMonth(date);
    };
    React.useEffect(function () {
        if (!context.month) {
            return;
        }
        if (isSameMonth(context.month, month)) {
            return;
        }
        setMonth(context.month);
    }, [context.month]);
    var displayMonths = getDisplayMonths(month, context);
    var nextMonth = getNextMonth(month, context);
    var previousMonth = getPreviousMonth(month, context);
    return (React.createElement(NavigationContext.Provider, { value: {
            month: month,
            displayMonths: displayMonths,
            goToMonth: goToMonth,
            previousMonth: previousMonth,
            nextMonth: nextMonth
        } }, props.children));
}
//# sourceMappingURL=NavigationProvider.js.map