import { addMonths, isSameMonth } from 'date-fns';
import { getNextMonth } from './getNextMonth';
var startingMonth = new Date(2020, 4, 31);
describe('when number of months is 1', function () {
    describe('when the navigation is disabled', function () {
        var disableNavigation = true;
        it('the next month is undefined', function () {
            var result = getNextMonth(startingMonth, { disableNavigation: disableNavigation });
            expect(result).toBe(undefined);
        });
    });
    describe('when in the navigable range', function () {
        var toDate = addMonths(startingMonth, 3);
        it('the next month is not undefined', function () {
            var result = getNextMonth(startingMonth, { toDate: toDate });
            var expectedNextMonth = addMonths(startingMonth, 1);
            expect(result && isSameMonth(result, expectedNextMonth)).toBeTruthy();
        });
    });
    describe('when not in the navigable range', function () {
        var toDate = startingMonth;
        it('the next month is undefined', function () {
            var result = getNextMonth(startingMonth, { toDate: toDate });
            expect(result).toBe(undefined);
        });
    });
});
describe('when displaying 3 months', function () {
    var numberOfMonths = 3;
    describe('when the navigation is paged', function () {
        var pagedNavigation = true;
        it('the next month is 3 months ahead', function () {
            var result = getNextMonth(startingMonth, {
                numberOfMonths: numberOfMonths,
                pagedNavigation: pagedNavigation
            });
            var expectedNextMonth = addMonths(startingMonth, 3);
            expect(result && isSameMonth(result, expectedNextMonth)).toBeTruthy();
        });
        describe('when the to-date is ahead less than 3 months', function () {
            it('the next month is undefined', function () {
                var result = getNextMonth(startingMonth, {
                    numberOfMonths: numberOfMonths,
                    pagedNavigation: pagedNavigation,
                    toDate: addMonths(startingMonth, 1)
                });
                expect(result).toBe(undefined);
            });
        });
    });
    describe('when the navigation is not paged', function () {
        var pagedNavigation = false;
        it('the next month is 1 months ahead', function () {
            var result = getNextMonth(startingMonth, {
                numberOfMonths: numberOfMonths,
                pagedNavigation: pagedNavigation
            });
            var expectedNextMonth = addMonths(startingMonth, 1);
            expect(result && isSameMonth(result, expectedNextMonth)).toBeTruthy();
        });
        describe('when the to-date is ahead less than 3 months', function () {
            it('the next month is undefined', function () {
                var result = getNextMonth(startingMonth, {
                    numberOfMonths: numberOfMonths,
                    pagedNavigation: pagedNavigation,
                    toDate: addMonths(startingMonth, 2)
                });
                expect(result).toBe(undefined);
            });
        });
    });
});
//# sourceMappingURL=getNextMonth.test.js.map