import { isAfter, isBefore, isSameDay } from 'date-fns';
/**
 * Add a day to an existing range.
 *
 * The returned range takes in account the `undefined` values and if the added
 * day is already present in the range.
 */
export function addToRange(day, range) {
    var _a = range || {}, from = _a.from, to = _a.to;
    if (!from) {
        return { from: day, to: day };
    }
    if (!to && isSameDay(from, day)) {
        return { from: undefined, to: undefined };
    }
    if (!to && isBefore(day, from)) {
        return { from: day, to: from };
    }
    if (!to) {
        return { from: from, to: day };
    }
    if (isSameDay(to, day) && isSameDay(from, day)) {
        return { from: undefined, to: undefined };
    }
    if (isSameDay(to, day)) {
        return { from: to, to: to };
    }
    if (isSameDay(from, day)) {
        return { from: undefined, to: undefined };
    }
    if (isAfter(from, day)) {
        return { from: day, to: to };
    }
    return { from: from, to: day };
}
//# sourceMappingURL=addToRange.js.map